#[non_exhaustive]pub struct ListNotebookMetadataInput {
pub filters: Option<FilterDefinition>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub work_group: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filters: Option<FilterDefinition>Search filter string.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
max_results: Option<i32>Specifies the maximum number of results to return.
work_group: Option<String>The name of the Spark enabled workgroup to retrieve notebook metadata for.
Implementations
Sourceimpl ListNotebookMetadataInput
impl ListNotebookMetadataInput
Sourcepub fn filters(&self) -> Option<&FilterDefinition>
pub fn filters(&self) -> Option<&FilterDefinition>
Search filter string.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
Specifies the maximum number of results to return.
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The name of the Spark enabled workgroup to retrieve notebook metadata for.
Sourceimpl ListNotebookMetadataInput
impl ListNotebookMetadataInput
Sourcepub fn builder() -> ListNotebookMetadataInputBuilder
pub fn builder() -> ListNotebookMetadataInputBuilder
Creates a new builder-style object to manufacture ListNotebookMetadataInput.