#[non_exhaustive]pub struct ListNotebookMetadataOutput {
pub next_token: Option<String>,
pub notebook_metadata_list: Option<Vec<NotebookMetadata>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
notebook_metadata_list: Option<Vec<NotebookMetadata>>The list of notebook metadata for the specified workgroup.
Implementations
Sourceimpl ListNotebookMetadataOutput
impl ListNotebookMetadataOutput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn notebook_metadata_list(&self) -> &[NotebookMetadata]
pub fn notebook_metadata_list(&self) -> &[NotebookMetadata]
The list of notebook metadata for the specified workgroup.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .notebook_metadata_list.is_none().
Sourceimpl ListNotebookMetadataOutput
impl ListNotebookMetadataOutput
Sourcepub fn builder() -> ListNotebookMetadataOutputBuilder
pub fn builder() -> ListNotebookMetadataOutputBuilder
Creates a new builder-style object to manufacture ListNotebookMetadataOutput.